@@ -389,20 +389,27 @@ Util_Autoload()
 	char *sub_dir;
 	/* we need local filesystem encoding for chdir, opendir etc */
 
-	/* auto-load from ~/.xchat2/ or %APPDATA%\X-Chat 2\ */
 	xdir = xchat_get_info(ph, "xchatdirfs");
-	Util_Autoload_from(xchat_get_info(ph, "xchatdirfs"));
 
-	/* auto-load from subdirectory plugins */
-	sub_dir = malloc (strlen (xdir) + 9);
+	/* don't pollute the filesystem with script files, this only causes misuse of the folders
+	 * only use ~/.config/hexchat/addons/ and %APPDATA%\HexChat\addons */
+#if 0
+	/* auto-load from ~/.config/hexchat/ or %APPDATA%\HexChat\ */
+	Util_Autoload_from(xchat_get_info(ph, "xchatdirfs"));
+#endif
+
+	/* auto-load from subdirectory addons */
+	sub_dir = malloc (strlen (xdir) + 8);
 	strcpy (sub_dir, xdir);
-	strcat (sub_dir, "/plugins");
+	strcat (sub_dir, "/addons");
 	Util_Autoload_from(sub_dir);
 	free (sub_dir);
 
-#ifdef WIN32	/* also auto-load C:\Program Files\XChat\Plugins\*.py */
+#if 0
+#ifdef WIN32	/* also auto-load C:\Program Files\HexChat\Plugins\*.py */
 	Util_Autoload_from(HEXCHATLIBDIR"/plugins");
 #endif
+#endif
 }
 
 static char *
@@ -437,9 +444,9 @@ Util_Expand(char *filename)
 		return expanded;
 	g_free(expanded);
 
-	/* Check if ~/.xchat2/<filename> exists. */
+	/* Check if ~/.config/hexchat/addons/<filename> exists. */
 	expanded = g_build_filename(xchat_get_info(ph, "xchatdir"),
-				    filename, NULL);
+				    "addons", filename, NULL);
 	if (g_file_test(expanded, G_FILE_TEST_EXISTS))
 		return expanded;
 	g_free(expanded);
