@@ -161,6 +161,8 @@ struct xchatprefs
 	int gui_pane_right_size;
 	int gui_pane_right_size_min;
 
+	int gui_chanlist_maxusers;
+	int gui_chanlist_minusers;
 	int gui_ulist_pos;
 	int tab_pos;
 
@@ -284,6 +286,7 @@ struct xchatprefs
 	unsigned int windows_as_tabs;
 	unsigned int indent_nicks;
 	unsigned int text_replay;
+	unsigned int text_replay_strip_color;
 	unsigned int show_marker;
 	unsigned int show_separator;
 	unsigned int thin_separator;
@@ -310,7 +313,6 @@ struct xchatprefs
 	unsigned int identd;
 	unsigned int emoticons;
 	unsigned int tab_icons;
-	unsigned int tab_xp;
 #endif
 
 	unsigned int ctcp_number_limit;	/*flood */
@@ -586,7 +588,7 @@ struct popup
 /* CL: get a random int in the range [0..n-1]. DON'T use rand() % n, it gives terrible results. */
 #define RAND_INT(n) ((int)(rand() / (RAND_MAX + 1.0) * (n)))
 
-#if defined(WIN32) && GLIB_CHECK_VERSION(2,4,0)
+#ifdef WIN32
 #define xchat_filename_from_utf8 g_locale_from_utf8
 #define xchat_filename_to_utf8 g_locale_to_utf8
 #else
