@@ -23,6 +23,7 @@
 
 #ifdef WIN32
 #include <windows.h>
+#include <io.h>
 #else
 #include <unistd.h>
 #endif
@@ -72,6 +73,7 @@
 #include "urlgrab.h"
 #include "userlistgui.h"
 #include "menu.h"
+#include "servlistgui.h"
 
 static GSList *submenu_list;
 
@@ -565,10 +567,8 @@ menu_destroy (GtkWidget *menu, gpointer objtounref)
 static void
 menu_popup (GtkWidget *menu, GdkEventButton *event, gpointer objtounref)
 {
-#if (GTK_MAJOR_VERSION != 2) || (GTK_MINOR_VERSION != 0)
 	if (event && event->window)
 		gtk_menu_set_screen (GTK_MENU (menu), gdk_drawable_get_screen (event->window));
-#endif
 
 	g_object_ref (menu);
 	g_object_ref_sink (menu);
@@ -1288,7 +1288,7 @@ static void
 menu_savebuffer (GtkWidget * wid, gpointer none)
 {
 	gtkutil_file_req (_("Select an output filename"), savebuffer_req_done,
-							current_sess, NULL, FRF_WRITE);
+							current_sess, NULL, NULL, FRF_WRITE);
 }
 
 static void
@@ -1746,8 +1746,6 @@ create_icon_menu (char *labeltext, void *stock_name, int is_stock)
 	return item;
 }
 
-#if GTK_CHECK_VERSION(2,4,0)
-
 /* Override the default GTK2.4 handler, which would make menu
    bindings not work when the menu-bar is hidden. */
 static gboolean
@@ -1761,9 +1759,6 @@ menu_canacaccel (GtkWidget *widget, guint signal_id, gpointer user_data)
 #endif
 }
 
-#endif
-
-
 /* === STUFF FOR /MENU === */
 
 static GtkMenuItem *
@@ -2139,10 +2134,8 @@ menu_create_main (void *accel_group, int bar, int away, int toplevel,
 	/* /MENU needs to know this later */
 	g_object_set_data (G_OBJECT (menu_bar), "accel", accel_group);
 
-#if GTK_CHECK_VERSION(2,4,0)
 	g_signal_connect (G_OBJECT (menu_bar), "can-activate-accel",
 							G_CALLBACK (menu_canacaccel), 0);
-#endif
 
 	/* set the initial state of toggles */
 	mymenu[MENUBAR_OFFSET].state = !prefs.hidemenu;
